@@ -254,8 +254,6 @@ Evolution::Book::~Book ()
 {
   if (book != NULL)
     g_object_unref (book);
-  if (view != NULL)
-    g_object_unref (view);
 }
 
 const std::string
