@@ -53,7 +53,7 @@ namespace Local
   {
   public:
 
-    ContactDecorator (gmref_ptr<Cluster> _cluster): cluster(_cluster)
+    ContactDecorator (ClusterPtr _cluster): cluster(_cluster)
     {}
 
     ~ContactDecorator ()
@@ -66,19 +66,19 @@ namespace Local
     const std::string get_description () const
     { return "\tComponent to push contacts into the local roster"; }
 
-    bool populate_menu (gmref_ptr<Ekiga::Contact> contact,
+    bool populate_menu (Ekiga::ContactPtr contact,
 			const std::string uri,
 			Ekiga::MenuBuilder &builder);
 
   private:
 
-    gmref_ptr<Cluster> cluster;
+    ClusterPtr cluster;
   };
 };
 
 
 bool
-Local::ContactDecorator::populate_menu (gmref_ptr<Ekiga::Contact> contact,
+Local::ContactDecorator::populate_menu (Ekiga::ContactPtr contact,
 					const std::string uri,
 					Ekiga::MenuBuilder &builder)
 {
@@ -86,12 +86,12 @@ Local::ContactDecorator::populate_menu (gmref_ptr<Ekiga::Contact> contact,
 
   if (cluster->is_supported_uri (uri)) {
 
-    gmref_ptr<Heap> heap(cluster->get_heap ());
+    HeapPtr heap(cluster->get_heap ());
 
     if (!heap->has_presentity_with_uri (uri)) {
 
       builder.add_action ("add", _("Add to local roster"),
-			  sigc::bind (sigc::mem_fun (&*heap, &Local::Heap::new_presentity),
+			  sigc::bind (sigc::mem_fun (heap.get (), &Local::Heap::new_presentity),
 				      contact->get_name (), uri));
       populated = true;
     }
