@@ -777,12 +777,17 @@ gm_smiley_chooser_button_new (void)
 
   self =
     (GmSmileyChooserButton*) g_object_new (GM_SMILEY_CHOOSER_BUTTON_TYPE, NULL);
+  gtk_button_set_use_underline (self, TRUE);
 
   /* if already possible (unlikely), initially set the toplevel reference */
   widget = gtk_widget_get_toplevel (GTK_WIDGET (self));
   if (widget &&
-      GTK_WIDGET_TOPLEVEL (widget) &&
-      GTK_IS_WINDOW (widget))
+#if GTK_CHECK_VERSION(2,18,0)
+      gtk_widget_is_toplevel (widget)
+#else
+      GTK_WIDGET_TOPLEVEL (widget)
+#endif
+      && GTK_IS_WINDOW (widget))
     {
       g_object_ref_sink (G_OBJECT (widget));
       self->priv->toplevel_window_handler[HANDLER_CONFIGURE] =
