@@ -28,7 +28,7 @@
  *     start the new one).
  */
 
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
 
 #include "gmcellrendererexpander.h"
 
