@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ typedef struct _MenuEntry {
   gboolean stock_is_theme;
   guint accel;
   MenuEntryType type;
-  GtkSignalFunc func;
+  GCallback func;
   GClosureNotify clofunc;
   gpointer data;
   GtkWidget *widget;
