@@ -192,14 +192,12 @@ add_combo_box (GtkComboBox         *combo_box,
   GtkTreeModel *model = NULL;
   GtkTreeIter iter;
 
-  gchar *option_string = NULL;
   gboolean found = FALSE;
-  
+
   if (!option)
     return;
 
   model = gtk_combo_box_get_model (combo_box);
-  option_string = g_locale_to_utf8 (option, -1, NULL, NULL, NULL);
 
   if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter)) {
 
@@ -209,7 +207,7 @@ add_combo_box (GtkComboBox         *combo_box,
       gtk_tree_model_get_value (GTK_TREE_MODEL (model), &iter, 0, &value);
       value_string = (gchar *) g_value_get_string (&value);
       if (g_ascii_strcasecmp  (value_string, option) == 0) {
-        gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
+        gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                             1, TRUE,
                             -1);
         g_value_unset(&value);
@@ -223,13 +221,11 @@ add_combo_box (GtkComboBox         *combo_box,
 
   if (!found) {
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-    gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
+    gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                         0, option,
                         1, TRUE,
                         -1);
   }
-
-  g_free (option_string);
 }
 
 static void
@@ -343,7 +339,7 @@ static void
 name_changed_cb (GtkEntry     *entry,
                  GtkAssistant *assistant)
 {
-  set_current_page_complete (assistant, gtk_entry_get_text_length (entry) > 0);
+  set_current_page_complete (assistant, (gtk_entry_get_text (entry))[0] != '\0');
 }
 
 
@@ -916,29 +912,24 @@ apply_connection_type_page (EkigaAssistant *assistant)
   /* Set the connection quality settings */
   switch (connection_type) {
     case NET_PSTN:
-      gm_conf_set_bool (VIDEO_CODECS_KEY "enable_video", FALSE);
-      break;
-
     case NET_ISDN:
-      gm_conf_set_bool (VIDEO_CODECS_KEY "enable_video", FALSE);
+      gm_conf_set_int (VIDEO_DEVICES_KEY "size", 0); //QCIF
+      gm_conf_set_int (VIDEO_CODECS_KEY "maximum_video_tx_bitrate", 32);
       break;
 
     case NET_DSL128:
       gm_conf_set_int (VIDEO_DEVICES_KEY "size", 0); //QCIF
       gm_conf_set_int (VIDEO_CODECS_KEY "maximum_video_tx_bitrate", 64);
-      gm_conf_set_bool (VIDEO_CODECS_KEY "enable_video", TRUE);
       break;
 
     case NET_DSL512:
       gm_conf_set_int (VIDEO_DEVICES_KEY "size", 3); // 320x240
       gm_conf_set_int (VIDEO_CODECS_KEY "maximum_video_tx_bitrate", 384);
-      gm_conf_set_bool (VIDEO_CODECS_KEY "enable_video", TRUE);
       break;
 
     case NET_LAN:
       gm_conf_set_int (VIDEO_DEVICES_KEY "size", 3); // 320x240
       gm_conf_set_int (VIDEO_CODECS_KEY "maximum_video_tx_bitrate", 1024);
-      gm_conf_set_bool (VIDEO_CODECS_KEY "enable_video", TRUE);
       break;
 
     case NET_CUSTOM:
@@ -1071,16 +1062,16 @@ prepare_audio_devices_page (EkigaAssistant *assistant)
   char **array;
 
   ringer = gm_conf_get_string (SOUND_EVENTS_KEY "output_device");
-  if (ringer == NULL)
-    ringer = g_strdup ("Default (PTLIB/ALSA)");
+  if (ringer == NULL || !ringer[0])
+    ringer = g_strdup (get_default_audio_device_name ());
 
   player = gm_conf_get_string (AUDIO_DEVICES_KEY "output_device");
-  if (player == NULL)
-    player = g_strdup ("Default (PTLIB/ALSA)");
+  if (player == NULL || !player[0])
+    player = g_strdup (get_default_audio_device_name ());
 
   recorder = gm_conf_get_string (AUDIO_DEVICES_KEY "input_device");
-  if (recorder == NULL)
-    recorder = g_strdup ("Default (PTLIB/ALSA)");
+  if (recorder == NULL || !recorder[0])
+    recorder = g_strdup (get_default_audio_device_name ());
 
   /* FIXME: We should use DetectDevices, however DetectDevices
    * works only for the currently selected audio and video plugins,
@@ -1189,6 +1180,10 @@ prepare_video_devices_page (EkigaAssistant *assistant)
   get_videoinput_devices_list (assistant->priv->core, device_list);
   array = convert_string_list (device_list);
   current_plugin = gm_conf_get_string (VIDEO_DEVICES_KEY "input_device");
+  if (current_plugin == NULL || !current_plugin[0]) {
+    g_free (current_plugin);
+    current_plugin = g_strdup (get_default_video_device_name (array));
+  }
   update_combo_box (GTK_COMBO_BOX (assistant->priv->video_device),
                     array, current_plugin);
   g_free (array);
@@ -1461,7 +1456,7 @@ ekiga_assistant_init (EkigaAssistant *assistant)
 
   assistant->priv->last_active_page = 0;
   assistant->priv->icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-                                                    "ekiga", 48,
+                                                    PACKAGE_NAME, 48,
                                                     (GtkIconLookupFlags) 0, NULL);
 
   create_welcome_page (assistant);
@@ -1653,11 +1648,9 @@ ekiga_assistant_new (Ekiga::ServiceCore *core)
   assistant->priv->connections.push_back (conn);
 
   /* Notifiers for the VIDEO_CODECS_KEY keys */
-  gm_conf_notifier_add (VIDEO_CODECS_KEY "enable_video",
-			kind_of_net_changed_nt, NULL);	     
-  gm_conf_notifier_add (VIDEO_CODECS_KEY "maximum_video_tx_bitrate", 
+  gm_conf_notifier_add (VIDEO_CODECS_KEY "maximum_video_tx_bitrate",
 			kind_of_net_changed_nt, NULL);
-  gm_conf_notifier_add (VIDEO_CODECS_KEY "temporal_spatial_tradeoff", 
+  gm_conf_notifier_add (VIDEO_CODECS_KEY "temporal_spatial_tradeoff",
 			kind_of_net_changed_nt, NULL);
 
   return GTK_WIDGET (assistant);
